@@ -26,6 +26,13 @@ class TestChannel(object):
         channel.create(random_users[0]["id"])
         assert channel.id is not None
 
+    def test_send_message_with_optinos(self, channel, random_user):
+        response = channel.send_message(
+            {"text": "hi"}, random_user["id"], skip_push=True
+        )
+        assert "message" in response
+        assert response["message"]["text"] == "hi"
+
     def test_send_event(self, channel, random_user):
         response = channel.send_event({"type": "typing.start"}, random_user["id"])
         assert "event" in response
@@ -251,3 +258,24 @@ class TestChannel(object):
         assert len(response) == 2
         assert response[0]["user"]["id"] == "jessica"
         assert response[1]["user"]["id"] == "john2"
+
+    def test_mute_unmute(self, client, channel, random_users):
+        user_id = random_users[0]["id"]
+        response = channel.mute(user_id, expiration=30000)
+        assert "channel_mute" in response
+        assert "expires" in response["channel_mute"]
+        assert response["channel_mute"]["channel"]["cid"] == channel.cid
+        assert response["channel_mute"]["user"]["id"] == user_id
+
+        response = client.query_channels(
+            {"muted": True, "cid": channel.cid}, user_id=user_id
+        )
+        print(response, channel.cid)
+        assert len(response["channels"]) == 1
+
+        channel.unmute(user_id)
+        response = client.query_channels(
+            {"muted": True, "cid": channel.cid},
+            user_id=user_id,
+        )
+        assert len(response["channels"]) == 0
